@@ -1,4 +1,5 @@
 import mylogging
+import warnings
 
 
 def warn_outside(message):
@@ -6,13 +7,15 @@ def warn_outside(message):
 
 
 def traceback_outside(message):
-
     try:
         print(10 / 0)
-
     except Exception:
-        mylogging.traceback("message")
+        mylogging.traceback(message)
 
 
 def info_outside(message):
     mylogging.info(message)
+
+
+def warn_to_be_filtered():
+    warnings.warn("It mean of empty slice it is")
